@@ -154,14 +154,12 @@ class DadaStor(object):
 
     def connect_external_client(self):
         return boto3.client(
-            "s3",
-            config=botocore.client.Config(signature_version=botocore.UNSIGNED),
+            "s3", config=botocore.client.Config(signature_version=botocore.UNSIGNED),
         )
 
     def connect_external_resource(self):
         return boto3.resource(
-            "s3",
-            config=botocore.client.Config(signature_version=botocore.UNSIGNED),
+            "s3", config=botocore.client.Config(signature_version=botocore.UNSIGNED),
         )
 
     def get_bucket(self):
@@ -487,11 +485,7 @@ class DadaStor(object):
     #  Special Methods
     # ///////////////////////
 
-    def external_download(
-        self,
-        url,
-        local_path: Optional[str] = None,
-    ) -> str:
+    def external_download(self, url, local_path: Optional[str] = None,) -> str:
         f"""
         Download a file from a public s3 bucket
         :param url: a full s3 url (eg: ``s3://bucket/key.txt``)
@@ -529,9 +523,7 @@ class DadaStor(object):
         """
         # initial dada_settings
         conf = {
-            "ErrorDocument": {
-                "Key": error_doc,
-            },
+            "ErrorDocument": {"Key": error_doc,},
             "IndexDocument": {"Suffix": index_doc},
         }
 
